# BlobStash Python FileTree

[![Travis](https://img.shields.io/travis/tsileo/blobstash-python-filetree.svg)](https://travis-ci.org/tsileo/blobstash-python-filetree)
&nbsp; &nbsp; [![PyPI](https://img.shields.io/pypi/v/blobstash-filetree.svg)](https://pypi.python.org/pypi/blobstash-filetree)
&nbsp; &nbsp; [![PyPI](https://img.shields.io/pypi/pyversions/blobstash-filetree.svg)](https://pypi.python.org/pypi/blobstash-filetree)
&nbsp; &nbsp; [![Docs](https://img.shields.io/badge/docs-latest-brightgreen.svg)](https://blobstash-python-filetree.a4.io/)
&nbsp; &nbsp;[![License](http://img.shields.io/badge/license-MIT-red.svg?style=flat)](https://raw.githubusercontent.com/tsileo/blobstash-python-filetree/master/LICENSE)

Client for [BlobStash](https://github.com/tsileo/blobstash) FileTree API.

See the [documentation](https://blobstash-python-filetree.a4.io/) for more details.
